"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.styling = void 0;
var _view = require("@codemirror/view");
var _state = require("@codemirror/state");
var _language = require("@codemirror/language");
var _highlight = require("@lezer/highlight");
var _langRust = require("@codemirror/lang-rust");
const isDark = () => document.documentElement.classList.contains("dark");
const darkModeUpdate = _state.StateEffect.define();
const darkModeWatcher = _view.ViewPlugin.define(view => {
  const observer = new MutationObserver(() => view.dispatch({
    effects: darkModeUpdate.of(isDark())
  }));
  observer.observe(document.documentElement, {
    attributeFilter: ["class"]
  });
  return {
    destroy: () => observer.disconnect()
  };
});
const darkMode = _state.StateField.define({
  create: () => isDark(),
  update: (value, transaction) => {
    for (const effect of transaction.effects) if (effect.is(darkModeUpdate)) return effect.value;
    return value;
  },
  provide: field => [_view.EditorView.darkTheme.from(field), darkModeWatcher]
});
const theme = _view.EditorView.baseTheme({
  "&dark .cm-cursor": {
    borderLeftColor: "white"
  },
  // See https://github.com/jupyterlab/jupyterlab/pull/15805
  ".cm-builtin > span": {
    color: "#005CC5"
  },
  "&dark .cm-builtin > span": {
    color: "#79B8FF"
  }
});
const lightHighlight = (0, _language.syntaxHighlighting)(_language.HighlightStyle.define([{
  tag: _highlight.tags.comment,
  color: "#6A737D"
}, {
  tag: _highlight.tags.string,
  color: "#032F62"
}, {
  tag: [_highlight.tags.literal, _highlight.tags.null, _highlight.tags.brace],
  color: "#005CC5"
}, {
  tag: [_highlight.tags.name, _highlight.tags.derefOperator],
  color: "#24292E"
}, {
  tag: [_highlight.tags.operator, _highlight.tags.keyword],
  color: "#D73A49"
}, {
  tag: _highlight.tags.definition(_highlight.tags.name),
  color: "#6F42C1"
}], {
  themeType: "light"
}));
const darkHighlight = (0, _language.syntaxHighlighting)(_language.HighlightStyle.define([{
  tag: _highlight.tags.comment,
  color: "#6A737D"
}, {
  tag: _highlight.tags.string,
  color: "#9ECBFF"
}, {
  tag: [_highlight.tags.literal, _highlight.tags.null, _highlight.tags.brace],
  color: "#79B8FF"
}, {
  tag: [_highlight.tags.name, _highlight.tags.derefOperator],
  color: "#E1E4E8"
}, {
  tag: [_highlight.tags.operator, _highlight.tags.keyword],
  color: "#F97583"
}, {
  tag: _highlight.tags.definition(_highlight.tags.name),
  color: "#B392F0"
}], {
  themeType: "dark"
}));
const styling = exports.styling = [darkMode, theme, lightHighlight, darkHighlight, _language.indentUnit.of("    "), (0, _langRust.rust)()];