import { fencePlugin } from '@ver5/markdown-it-fence';
import stringify from 'simple-stringify';
import vm from 'node:vm';

const getCodeConfig = (configRaw) => {
  if (!/[{|}]/.test(configRaw))
    return null;
  try {
    const evalConfigStr = `(() => (${configRaw} || {}))()`;
    return vm.runInNewContext(evalConfigStr);
  } catch (e) {
    return null;
  }
};
const checkCodeIntegrity = (lang, rawCode) => {
  switch (lang) {
    case "rust":
      return /fn main\s*\(/.test(rawCode);
    case "c":
      return /main\s*\(/.test(rawCode);
    default:
      return true;
  }
};

const rustPlaygroundPlugin = (md, options = {}) => {
  const lang = "rust";
  const fence = md.renderer.rules.fence;
  md.use(fencePlugin).renderer.rules.fence = (...args) => {
    const [tokens, idx] = args;
    const { info, content: rawCode } = tokens[idx];
    if (info === "txt") {
      tokens[idx].info = "txt:no-line-numbers";
    }
    let htmlCode = "";
    if (/rust/.test(info)) {
      tokens[idx].info = lang;
      htmlCode = fence(...args);
      const _info = tokens[idx]._info;
      const noRun = /(,|\s)no_run/.test(_info);
      if (noRun) {
        tokens[idx].info = lang;
        htmlCode = htmlCode.replace(/"(language-rust)/, '"$1 no_run');
        return htmlCode;
      }
      let execOptions = {};
      const match = tokens[idx]._info.match(/:({.*?})/);
      const configRaw = match && match[1] && match[1].trim() || "";
      if (configRaw) {
        execOptions = { ...options, ...getCodeConfig(configRaw) };
      }
      if (checkCodeIntegrity(lang, rawCode)) {
        htmlCode = htmlCode + `<RustPlayground ${stringify.json(execOptions, 2)} id="${Math.random().toString(16).slice(2)}"/>`;
      }
    } else {
      htmlCode = fence(...args);
    }
    return htmlCode;
  };
};

export { rustPlaygroundPlugin };
//# sourceMappingURL=index.mjs.map
