"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.boolify = boolify;
exports.checkCodeIntegrity = void 0;
exports.fetchWithTimeout = fetchWithTimeout;
exports.isShellCode = exports.isRustCode = exports.getCodeConfig = void 0;
var _nodeVm = _interopRequireDefault(require("node:vm"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const getCodeConfig = configRaw => {
  if (!/[{|}]/.test(configRaw)) return null;
  try {
    const evalConfigStr = `(() => (${configRaw} || {}))()`;
    return _nodeVm.default.runInNewContext(evalConfigStr);
  } catch (e) {
    return null;
  }
};
exports.getCodeConfig = getCodeConfig;
const isRustCode = html => /language-rust/.test(html);
exports.isRustCode = isRustCode;
const isShellCode = html => /language-(shellscript|shell|bash|sh|zsh)/.test(html);
exports.isShellCode = isShellCode;
const checkCodeIntegrity = (lang, rawCode) => {
  switch (lang) {
    case "rust":
      return /fn main\s*\(/.test(rawCode);
    case "c":
      return /main\s*\(/.test(rawCode);
    default:
      return true;
  }
};
exports.checkCodeIntegrity = checkCodeIntegrity;
function fetchWithTimeout(url, options, timeout = 12e3) {
  return Promise.race([fetch(url, options), new Promise((_, reject) => setTimeout(() => reject(new Error(`Request timed out after ${timeout}ms`)), timeout))]);
}
function convert(str) {
  switch (str.toLowerCase()) {
    case "true":
      return true;
    case "false":
      return false;
    default:
      return str;
  }
}
function boolify(obj) {
  if (typeof obj === "boolean") return obj;
  if (typeof obj === "string") return convert(obj);
  if (toString.call(obj) === "[object Object]") {
    const keys = Object.keys(obj);
    for (let i = 0, l = keys.length; i < l; i++) {
      obj[keys[i]] = boolify(obj[keys[i]]);
    }
  }
  return obj;
}