import vm from "node:vm";
export const getCodeConfig = (configRaw) => {
  if (!/[{|}]/.test(configRaw)) return null;
  try {
    const evalConfigStr = `(() => (${configRaw} || {}))()`;
    return vm.runInNewContext(evalConfigStr);
  } catch (e) {
    return null;
  }
};
export const isRustCode = (html) => /language-rust/.test(html);
export const isShellCode = (html) => /language-(shellscript|shell|bash|sh|zsh)/.test(html);
export const checkCodeIntegrity = (lang, rawCode) => {
  switch (lang) {
    case "rust":
      return /fn main\s*\(/.test(rawCode);
    case "c":
      return /main\s*\(/.test(rawCode);
    default:
      return true;
  }
};
export function fetchWithTimeout(url, options, timeout = 12e3) {
  return Promise.race([
    fetch(url, options),
    new Promise((_, reject) => setTimeout(() => reject(new Error(`Request timed out after ${timeout}ms`)), timeout))
  ]);
}
function convert(str) {
  switch (str.toLowerCase()) {
    case "true":
      return true;
    case "false":
      return false;
    default:
      return str;
  }
}
export function boolify(obj) {
  if (typeof obj === "boolean") return obj;
  if (typeof obj === "string") return convert(obj);
  if (toString.call(obj) === "[object Object]") {
    const keys = Object.keys(obj);
    for (let i = 0, l = keys.length; i < l; i++) {
      obj[keys[i]] = boolify(obj[keys[i]]);
    }
  }
  return obj;
}
